import Api from '../helpers/api';

class FieldReportsApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'field-reports';
  }

  evidence(fieldReportId, params) {
    const url = `${this.getUrl()}/${fieldReportId}/evidence${this.getUrlParams(
      params
    )}`;

    const all = async () => {
      return await this.get(url);
    };

    const attach = async (formData) => {
      return await this.post(url, formData);
    };

    const detach = async (evidenceId, fileType = 'images') => {
      const url = `${this.getUrl()}/${fieldReportId}/evidence/${fileType}/${evidenceId}${this.getUrlParams()}`;
      return await this.post(url, null, 'delete');
    };

    return {
      all,
      attach,
      detach,
    };
  }

  blockchain(fieldReportId, params) {
    const url = `${this.getUrl()}/${fieldReportId}${this.getUrlParams(params)}`;
    return this.get(url);
  }

  initiatives(fieldReportId, params) {
    const all = async () => {
      const url = `${this.getUrl()}/${fieldReportId}/initiatives${this.getUrlParams(
        params
      )}`;
      return await this.get(url);
    };

    return { all };
  }

  attachInitiatives(fieldReportId, formData, params) {
    const url = `${this.getUrl()}/${fieldReportId}/attach-initiatives${this.getUrlParams(
      params
    )}`;

    return this.post(url, formData, null, params);
  }

  detachInitiatives(fieldReportId, formData, params) {
    const url = `${this.getUrl()}/${fieldReportId}/detach-initiatives${this.getUrlParams(
      params
    )}`;

    return this.post(url, formData, null, params);
  }

  mapTiles(fieldReportId, params) {
    const url = `${this.getUrl()}/${fieldReportId}/map-tiles${this.getUrlParams(
      params
    )}`;

    const attach = async (base64String) => {
      return await this.post(url, base64String);
    };

    return {
      attach,
    };
  }

  phases() {
    const all = async () => {
      const url = `${this.getUrl()}/phases`;
      return await this.get(url);
    };

    return { all };
  }
}

export const FieldReports = new FieldReportsApi();
