import Api from "../helpers/api";

class OrganizationsApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = "organizations";
  }

  tasks(orgId) {
    let url = `${this.getUrl()}/${orgId}/tasks`;

    const all = async (params) => {
      url = `${url}${this.getUrlParams(params)}`;
      return await this.get(url);
    };

    const create = async (data) => {
      url = `${url}${this.getUrlParams()}`;
      return await this.post(url, data);
    };

    return {
      all,
      create,
    };
  }

  taskCategories(orgId) {
    let url = `${this.getUrl()}/${orgId}/task-categories`;

    const all = async (params) => {
      url = `${url}${this.getUrlParams(params)}`;
      return await this.get(url);
    };

    const create = async (data) => {
      url = `${url}${this.getUrlParams()}`;
      return await this.post(url, data);
    };

    return {
      all,
      create,
    };
  }

  plantingStats(orgId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${orgId}/field-updates/planting-stats${this.getUrlParams(
        params
      )}`;
      return await this.get(url);
    };

    return { all };
  }

  pins(orgId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${orgId}/pins/${this.getUrlParams(params)}`;

      return await this.get(url);
    };

    const single = async (pinId, params) => {
      const url = `${this.getUrl()}/${orgId}/pins/${pinId}${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    const create = async (data, params) => {
      const url = `${this.getUrl()}/${orgId}/pins${this.getUrlParams(params)}`;

      return await this.post(url, data);
    };

    return {
      all,
      single,
      create,
    };
  }

  metrics(orgId) {
    const all = async (args) => {
      const url = `${this.getUrl()}/${orgId}/metrics${this.getUrlParams(args)}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  plantingReport(orgId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${orgId}/planting-report${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    return {
      all,
    };
  }
}

export const Organizations = new OrganizationsApi();
