import Api from '../helpers/api';
import Team from '../helpers/team';
import { getSession } from '../helpers/session';

class OrgsApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'orgs';
  }

  users(orgIdAs) {
    const orgId = orgIdAs ? orgIdAs : getSession().orgId;
    return Team(this, orgId);
  }

  async roles(orgId, params) {
    const url = `${this.getUrl()}/${orgId}/roles${this.getUrlParams(params)}`;
    return await this.get(url);
  }

  async emails(orgId, data, params) {
    const url = `${this.getUrl()}/${orgId}/emails${this.getUrlParams(params)}`;
    return await this.post(url, data);
  }

  async stats() {
    const url = `${this._geStatstUrl()}`;
    return await this.get(url);
  }

  async publicStats() {
    const url = `${this._geStatstUrl(true)}`;
    return await this.get(url);
  }

  siteManagers(orgId) {
    const locations = () => {
      const all = async (userId) => {
        const url = `${this.getUrl()}/${orgId}/site-managers/${userId}/locations${this.getUrlParams()}`;
        return await this.get(url);
      };

      const update = async (data) => {
        const url = `${this.getUrl()}/${orgId}/site-managers/locations${this.getUrlParams()}`;
        return await this.post(url, data, 'put');
      };

      return {
        all,
        update,
      };
    };

    return {
      locations,
    };
  }

  _geStatstUrl(isPublic) {
    const endpoint = isPublic ? 'pstats' : 'stats';
    return `${this.getUrl()}/${endpoint}${this.getUrlParams()}`;
  }
}

export const Orgs = new OrgsApi();
