import Api from "../helpers/api";

/**
 * This is a namespace that contains documentation elements 
 * belonging to the Password domain.
 *
 * @namespace Password
 */
class PasswordApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = "password";
  }

  recovery() {
    /**
     * Sends a recovery password email to the specified email address.
     *
     * @param {Object} data - An object containing the following properties:
     * @param {string} data.email - The email address to send the recovery email to.
     * @param {string} [data.return_url] - The URL to redirect the user to after they reset their password.
     * @returns {Promise<boolean>} - A Promise that resolves to a boolean indicating whether the email was sent successfully.
     */
    const post = async (data) => {
      const url = `${this.getUrl()}/email`;

      return await this.post(url, data);
    };

    return {
      post,
    };
  }

  reset() {
    /**
     * Sends a POST request to reset a password with the specified email, token, and password.
     *
     * @param {Object} data - An object containing the following properties:
     *   @param {string} data.email - The email address of the user whose password is being reset.
     *   @param {string} data.token - The token associated with the password reset request.
     *   @param {string} data.password - The new password to set for the user.
     *   @param {string} data.password_confirmation - The new password confimation to set for the user.
     * @returns {Promise<Object>} - A Promise that resolves to the result of the POST request.
     */
    const post = async (data) => {
      const url = `${this.getUrl()}/reset`

      return await this.post(url, data);
    };

    return {
      post,
    };
  }
}

export const Password = new PasswordApi();
