import Api from '../helpers/api';

class PlantingSitesApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'planting-sites';
  }

  public() {
    const all = async (params) => {
      const url = `${this.getUrl()}/public${this.getUrlParams(
        params
      )}`;
      return await this.get(url);
    };

    const single = async (plantingSiteId) => {
      const url = `${this.getUrl()}/public/${plantingSiteId}`;
      return await this.get(url);
    };

    return {
      all,
      single,
    };
  }

  users(plantingSiteId) {
    let url = `${this.getUrl()}/${plantingSiteId}/users`;

    const all = async (params) => {
      url = `${url}${this.getUrlParams(params)}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  images(subsiteId) {
    let url = `${this.getUrl()}/${subsiteId}/media/images`;

    const attach = async (data, params) => {
      url = `${url}${this.getUrlParams(params)}`;

      return await this.post(url, data);
    };

    const remove = async (imageId, params) => {
      url = `${this.getUrl()}/${subsiteId}/media/images/${imageId}${this.getUrlParams(
        params
      )}`;
      return await this.post(url, null, 'delete');
    };

    return {
      attach,
      delete: remove,
    };
  }

  attachments(subsiteId) {
    let url = `${this.getUrl()}/${subsiteId}/media/attachments`;

    const attach = async (data, params) => {
      url = `${url}${this.getUrlParams(params)}`;

      return await this.post(url, data);
    };

    const remove = async (attachmentId, params) => {
      url = `${this.getUrl()}/${subsiteId}/media/attachments/${attachmentId}${this.getUrlParams(
        params
      )}`;
      return await this.post(url, null, 'delete');
    };

    return {
      attach,
      delete: remove,
    };
  }

  stakeholders(plantingSiteId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${plantingSiteId}/stakeholders${this.getUrlParams(
        params
      )}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  evidence(subsiteId, params) {
    let url = `${this.getUrl()}/${subsiteId}/evidence`;

    console.log(url);

    const all = async () => {
      url = `${url}${this.getUrlParams(params)}`;
      return await this.get(url);
    };

    const attach = async (formData) => {
      url = `${url}${this.getUrlParams(params)}`;
      return await this.post(url, formData);
    };

    const remove = async (evidenceType, evidenceId) => {
      url = `${url}/${evidenceType}/${evidenceId}${this.getUrlParams(params)}`;

      return await this.post(url, null, 'delete');
    };

    return {
      all,
      attach,
      delete: remove,
    };
  }

  stats(subsiteId) {
    const all = async (args) => {
      const url = `${this.getUrl()}/${subsiteId}/stats${this.getUrlParams(
        args
      )}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  pstats(subsiteId) {
    const all = async (args) => {
      const url = `${this.getUrl()}/${subsiteId}/pstats${this.getUrlParams(
        args
      )}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  locations() {
    const all = async (params) => {
      const url = `${this.getUrl()}/locations-by-org${this.getUrlParams(
        params
      )}`;
      return await this.get(url);
    };

    return {
      all
    }
  }
}

export const PlantingSites = new PlantingSitesApi();
