import Api from '../helpers/api';

class ResellersApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'resellers';
  }

  statsSold() {
    const all = async () => {
      const url = `${this.getUrl()}/1/pstats/sold?pretty=1`;
      let response;
      try {
        response = await this.get(url);
      } catch (e) {
        console.log('error ', e);
      }
      return response;
    };

    return {
      all,
    };
  }

  statsPurchased() {
    const all = async () => {
      const url = `${this.getUrl()}/1/pstats/purchased?pretty=1`;
    };

    return {
      all,
    };
  }

  /**
   * Creates a sales report object with methods to fetch sales data for a specific reseller.
   *
   * @param {string} resellerId - The unique identifier of the reseller for which the sales report is generated.
   * @returns {Object} An object with methods to retrieve sales data.
   * @memberof Resellers
   */
  salesReport(resellerId) {
    /**
     * Fetches all sales data for the specified reseller.
     *
     * @param {Object} params - Additional parameters for customizing the request.
     * @param {string} params.format - The desired format of the sales report (e.g., 'csv', 'json').
     * @returns {Promise} A promise that resolves to the sales data.
     * @memberof Resellers.salesReport
     */
    const all = async (params) => {
      const url = `${this.getUrl()}/${resellerId}/sales-report${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    return {
      all,
    };
  }

  /**
   * Creates an allocation progress report object with methods to fetch allocation progress data for a specific reseller.
   *
   * @param {string} resellerId - The unique identifier of the reseller for which the allocation progress report is generated.
   * @returns {Object} An object with methods to retrieve allocation progress data.
   * @memberof Resellers
   */
  allocationProgressReport(resellerId) {
    /**
     * Fetches all allocation progress data for the specified reseller.
     *
     * @param {Object} params - Additional parameters for customizing the request.
     * @returns {Promise} A promise that resolves to the allocation progress data.
     * @memberof Resellers.allocationProgressReport
     */
    const all = async (params) => {
      const url = `${this.getUrl()}/${resellerId}/allocation-progress-report${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    return {
      all,
    };
  }

  /**
   * Fetches all planting parter organizations for the specified reseller.
   *
   * @param {string} resellerId - The unique identifier of the reseller.
   * @param {Object} params - Additional parameters for customizing the request.
   * @returns {Promise} A promise that resolves to the organizations data.
   * @memberof Resellers
   */
  organizations(resellerId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${resellerId}/organizations${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    return {
      all,
    };
  }
}

export const Resellers = new ResellersApi();
