import Api from '../helpers/api';

class SponsorsApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'sponsors';
  }

  async map() {
    this.setOrg();

    if (!this.orgId) {
      throw new Error('No org id provided');
    }

    const url = `${this.getUrl()}/${this.orgId}/map-data`;
    return await this.get(url);
  }

  async profile() {
    this.setOrg();

    if (!this.orgId) {
      throw new Error('No org id provided');
    }

    const url = `${this.getUrl()}/${this.orgId}/profile`;
    return await this.get(url);
  }

  async plantingStats(args) {
    const url = `${this.getUrl()}/planting-stats${this.getUrlParams(args)}`;
    return await this.get(url);
  }

  async totalPlantingStats(args) {
    const url = `${this.getUrl()}/total-planting-stats${this.getUrlParams(
      args
    )}`;
    return await this.get(url);
  }

  cms(args) {
    const urlParams = this.getUrlParams(args);

    const token = async () => {
      const url = `${this.getUrl()}/${this.orgId}/cms/token${urlParams}`;
      return await this.get(url);
    };

    const imageUploadUrl = async () => {
      const url = `${this.getUrl()}/${
        this.orgId
      }/cms/image-upload-url${urlParams}`;
      return await this.get(url);
    };

    const credentials = async (orgId, data) => {
      const url = `${this.getUrl()}/${orgId}/cms/credentials${urlParams}`;
      return await this.post(url, data);
    };

    return {
      token,
      imageUploadUrl,
      credentials,
    };
  }

  tools(args) {
    const get = async (sponsorId) => {
      const url = `${this.getUrl()}/${sponsorId}/tools${this.getUrlParams(
        args
      )}`;
      return await this.get(url);
    };

    const create = async (sponsorId, data) => {
      const url = `${this.getUrl()}/${sponsorId}/tools`;
      return await this.post(url, data);
    };

    return {
      get,
      create,
    };
  }

  treeOrderSummary(args) {
    const all = async (sponsorId) => {
      const url = `${this.getUrl()}/${sponsorId}/tree-order-summary${this.getUrlParams(
        args
      )}`;

      return await this.get(url);
    };

    return {
      all,
    };
  }

  region(regionId, args) {
    this.setOrg();

    const stats = () => {
      const all = async () => {
        const url = `${this.getUrl()}/${
          this.orgId
        }/regions/${regionId}/stats${this.getUrlParams(args)}`;

        return await this.get(url);
      };

      return {
        all,
      };
    };

    return {
      stats,
    };
  }

  metrics(sponsorId) {
    const all = async (args) => {
      const url = `${this.getUrl()}/${sponsorId}/metrics${this.getUrlParams(
        args
      )}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  pins(orgId) {
    const all = async (params) => {
      const url = `${this.getUrl()}/${orgId}/pins/${this.getUrlParams(params)}`;

      return await this.get(url);
    };

    const single = async (pinId, params) => {
      const url = `${this.getUrl()}/${orgId}/pins/${pinId}${this.getUrlParams(
        params
      )}`;

      return await this.get(url);
    };

    return {
      all,
      single,
    };
  }
}

export const Sponsors = new SponsorsApi();
