import Api from '../helpers/api';
import { createParamsStringFromArgs } from '../utils/args';

class StandardsApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = 'standards';
  }

  themes() {
    const single = async (id, args) => {
      const url = `${this.getUrl()}/themes/${id}?${createParamsStringFromArgs(
        args
      )}`;
      return await this.get(url);
    };

    const all = async (args) => {
      const url = `${this.getUrl()}/themes?${createParamsStringFromArgs(args)}`;
      return await this.get(url);
    };

    const create = async (data, args) => {
      const url = `${this.getUrl()}/themes?${createParamsStringFromArgs(args)}`;
      return await this.post(url, data);
    };

    const update = async (themeId, data, args) => {
      const url = `${this.getUrl()}/themes/${themeId}?${createParamsStringFromArgs(
        args
      )}`;
      return await this.post(url, data, 'patch');
    };

    const remove = async (themeId, args) => {
      const url = `${this.getUrl()}/themes/${themeId}?${createParamsStringFromArgs(
        args
      )}`;
      return await this.post(url, null, 'delete');
    };

    const goals = (themeId) => {
      const create = async (data, args) => {
        const url = `${this.getUrl()}/themes/${themeId}/goals?${createParamsStringFromArgs(
          args
        )}`;
        return await this.post(url, data);
      };

      const indicators = (goalId) => {
        const create = async (data, args) => {
          const url = `${this.getUrl()}/themes/${themeId}/goals/${goalId}/indicators?${createParamsStringFromArgs(
            args
          )}`;
          return await this.post(url, data);
        };

        return {
          create,
        };
      };

      return {
        create,
        indicators,
      };
    };

    const UNSDGs = (themeId) => {
      const create = async (data) => {
        const url = `${this.getUrl()}/themes/${themeId}/attach-sdg`;
        return await this.post(url, data);
      };
      return {
        create,
      };
    };

    return {
      single,
      all,
      create,
      update,
      delete: remove,
      goals,
      UNSDGs,
    };
  }

  goals(goalId) {
    const single = async () => {
      const url = `${this.getUrl()}/goals/${goalId}`;
      return await this.get(url);
    };

    const update = async (data, args) => {
      const url = `${this.getUrl()}/goals/${goalId}${this.getUrlParams(args)}`;
      return await this.post(url, data, 'patch');
    };

    const remove = async () => {
      const url = `${this.getUrl()}/goals/${goalId}`;
      return await this.post(url, null, 'delete');
    };

    return {
      single,
      update,
      delete: remove,
    };
  }

  goalsThemes(goalId) {
    let url = `${this.getUrl()}/goals-themes/${goalId}`;

    const single = async () => {
      return await this.get(url);
    };

    const detach = async (themeId) => {
      const args = { id: themeId };
      url = `${url}${this.getUrlParams(args)}`;
      return await this.post(url, null, 'delete');
    };

    return {
      single,
      delete: detach,
    };
  }

  indicators(indicatorId) {
    const single = async () => {
      const url = `${this.getUrl()}/indicators/${indicatorId}`;
      return await this.get(url);
    };

    const update = async (data) => {
      const url = `${this.getUrl()}/indicators/${indicatorId}`;
      return await this.post(url, data, 'patch');
    };

    const remove = async () => {
      const url = `${this.getUrl()}/indicators/${indicatorId}`;
      return await this.post(url, null, 'delete');
    };

    return {
      single,
      update,
      delete: remove,
    };
  }

  UNSDGs(themeId) {
    const attach = async (data) => {
      const url = `${this.getUrl()}/themes/${themeId}/attach-sdg`;
      return await this.post(url, { sdg_id: data });
    };

    const remove = async (data) => {
      const url = `${this.getUrl()}/themes/${themeId}/detach-sdg`;
      return await this.post(url, { sdg_id: data });
    };

    return {
      attach,
      remove,
    };
  }
}

export const Standards = new StandardsApi();
