import Api from "../helpers/api";
import { createParamsStringFromArgs } from "../utils/args";

class SubsitesApi extends Api {
  constructor(resource) {
    super(resource);
    this.resource = "subsites";
  }

  locationsByOrg() {
    const get = async (args) => {
      const url = `${this.getUrl()}/locations-by-org${this.getUrlParams(args)}`;
      return await this.get(url);
    };

    return {
      get,
    };
  }

  indicators() {
    const all = async (subsite, args) => {
      const url = `${this.getUrl()}/${subsite}/indicators?${createParamsStringFromArgs(
        args
      )}`;
      return await this.get(url);
    };

    const create = async (subsite, formData) => {
      const url = `${this.getUrl()}/${subsite}/indicators`;
      return await this.post(url, formData);
    };

    const remove = async (subsite, indicator) => {
      const url = `${this.getUrl()}/${subsite}/indicators/${indicator}`;
      return await this.post(url, null, "delete");
    };

    return {
      all,
      create,
      delete: remove,
    };
  }

  stats(subsiteId, args) {
    const all = async () => {
      const url = `${this.getUrl()}/${subsiteId}/stats${this.getUrlParams(args)}`;
      return await this.get(url);
    };

    return {
      all,
    };
  }

  evidence(subsiteId, params) {
    let url = `${this.getUrl()}/${subsiteId}/evidence`;

    const all = async () => {
      url = `${url}${this.getUrlParams(params)}`;

      return await this.get(url);
    };

    const attach = async (formData) => {
      url = `${url}${this.getUrlParams(params)}`;

      return await this.post(url, formData);
    };

    const remove = async (evidenceType, evidenceId) => {
      url = `${url}/${evidenceType}/${evidenceId}${this.getUrlParams(
        params
      )}`;

      return await this.post(url, null, "delete");
    };

    return {
      all,
      attach,
      delete: remove,
    };
  }
}

export const Subsites = new SubsitesApi();
