/**
 * Creates an abstract team object that can be used 
 * for CRUD operations related to an org users.
 * 
 * @param {object} api 
 * @param {number} id 
 * @returns {object} 
 */
const Team = (api, id) => {
  let url = `${api.baseUrl}/${api.resource}/${id}/users`;

  const all = async (params) => {
    url = `${url}${api.getUrlParams(params)}`;
    return await api.get(url);
  };

  const single = async (userId, params) => {
    url = `${url}/${userId}${api.getUrlParams(params)}`;
    return await api.get(url);
  };

  const create = async (data, params) => {
    url = `${url}${api.getUrlParams(params)}`;
    return await api.post(url, data);
  }

  const update = async (userId, data, params) => {
    url = `${url}/${userId}${api.getUrlParams(params)}`;
    return await api.post(url, data, 'patch');
  }

  const remove = async (userId, params) => {
    url = `${url}/${userId}${api.getUrlParams(params)}`;
    return await api.post(url, null, "delete");
  }

  return {
    all,
    single,
    create,
    update,
    delete: remove
  };
};

export default Team;