export const createParamsStringFromArgs = (args) => {
  if (!args && typeof args !== "object" && !Array.isArray(args)) {
    return "";
  }

  const paramsString = [];
  let arr = [];

  Object.entries(args).forEach(([key, value]) => {
    if (value === null) return;

    if (Array.isArray(value)) {
      arr = value
        .filter((item) => item !== undefined && item !== null && item !== "")
        .map((item, index) => {
          const param = `${key}[]=${encodeURIComponent(item)}`;

          return index === 0 ? `${param}` : `&${param}`;
        })
        .join("");

      if (!arr.length) {
        return;
      }

      paramsString.push(arr);
    } else {
      if (value !== undefined) {
        /**
         * as args is an object, we can't pass same keys
         * and sometimes the api might need the keys
         * to be equal (e.g box=1&box=2...). As a
         * solution, we have this -x- to allow
         * same keys to be passed. The args
         * would look like:
         *
         * {
         *  'box-x-1': 1
         *  'box-x-2': 2
         * }
         *
         * and would be translated as expected:
         *
         * box=1&box=2
         */
        paramsString.push(
          `${key.split("-x-")[0]}=${encodeURIComponent(value)}`
        );
      }
    }
  });

  return paramsString.length ? `&${paramsString.join("&")}` : "";
};
